==> lms-1.4.0rc1+libs.tar.gz: lms/modules/adminadd.php <==
<?php

/*
 * LMS version 1.4.0rc1 Evalla
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: adminadd.php,v 1.28.2.1 2004/09/18 19:14:53 alec Exp $
 */

$adminadd = $_POST['adminadd'];
$acl = $_POST['acl'];

if(isset($adminadd))
{
	foreach($adminadd as $key => $value)
		$adminadd[$key] = trim($value);
	
	if($adminadd['login']==""&&$adminadd['name']==""&&$adminadd['password']==""&&$adminadd['confirm']=="")
	{
		header("Location: ?m=adminadd");
		die;
	}
	
	if($LMS->GetAdminIDByLogin($adminadd['login']))
		$error['login'] = "Podany login istnieje!";
	elseif(!eregi("^[a-z0-9.-_]+$",$adminadd['login']))
		$error['login'] = "Login zawiera niepoprawne znaki!";

	if($adminadd['email']!="" && !check_email($adminadd['email']))
		$error['email'] = "Podany email nie wydaje si by poprawny!";

	if($adminadd['password']=="")
		$error['password'] = "Haso nie moe by puste!";
	elseif($adminadd['password']!=$adminadd['confirm'])
		$error['password'] = "Hasa nie s takie same!";

	// zrbmy mask ACL...

	for($i=0;$i<256;$i++)
		$mask .= "0";

	foreach($access['table'] as $idx => $row)
		if($acl[$idx]=="1")
			$mask[255-$idx] = "1";

	for($i=0;$i<256;$i += 4)
		$outmask = $outmask . dechex(bindec(substr($mask,$i,4)));

	$adminadd['rights'] = ereg_replace('^[0]*(.*)$','\1',$outmask);

	if(!$error)
	{
		header("Location: ?m=admininfo&id=".$LMS->AdminAdd($adminadd));
		die;
	}
}
foreach($access['table'] as $idx => $row)
{
	$row['id'] = $idx;
	if($acl[$idx] == "1")
		$row['enabled'] = TRUE;
	$accesslist[] = $row;
}

$layout['pagetitle'] = "Nowy administrator";
$SMARTY->assign('adminadd',$adminadd);
$SMARTY->assign('error',$error);
$SMARTY->assign('accesslist',$accesslist);
$SMARTY->display('adminadd.html');

?>

==> lms-1.4.5+libs.tar.gz: lms/modules/adminadd.php <==
<?php

/*
 * LMS version 1.4.5 Persus
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: adminadd.php,v 1.28.2.3 2005/02/26 17:35:03 alec Exp $
 */

$adminadd = $_POST['adminadd'];
$acl = $_POST['acl'];

if(isset($adminadd))
{
	foreach($adminadd as $key => $value)
		$adminadd[$key] = trim($value);
	
	if($adminadd['login']==""&&$adminadd['name']==""&&$adminadd['password']==""&&$adminadd['confirm']=="")
	{
		header("Location: ?m=adminadd");
		die;
	}
	
	if($adminadd['login']=="")
		$error['login'] = "Login nie moe by pusty!";
	elseif(!eregi("^[a-z0-9.-_]+$",$adminadd['login']))
		$error['login'] = "Login zawiera niepoprawne znaki!";
	elseif($LMS->GetAdminIDByLogin($adminadd['login']))
		$error['login'] = "Konto z podanym loginem istnieje lub login ten by ju wykorzystany w przeszoci!";

	if($adminadd['email']!="" && !check_email($adminadd['email']))
		$error['email'] = "Podany email nie wydaje si by poprawny!";

	if($adminadd['name']=="")
		$error['name'] = "Pole 'imi i nazwisko' nie moe by puste!";

	if($adminadd['password']=="")
		$error['password'] = "Haso nie moe by puste!";
	elseif($adminadd['password']!=$adminadd['confirm'])
		$error['password'] = "Hasa nie s takie same!";

	// zrbmy mask ACL...

	for($i=0;$i<256;$i++)
		$mask .= "0";

	foreach($access['table'] as $idx => $row)
		if($acl[$idx]=="1")
			$mask[255-$idx] = "1";

	for($i=0;$i<256;$i += 4)
		$outmask = $outmask . dechex(bindec(substr($mask,$i,4)));

	$adminadd['rights'] = ereg_replace('^[0]*(.*)$','\1',$outmask);

	if(!$error)
	{
		header("Location: ?m=admininfo&id=".$LMS->AdminAdd($adminadd));
		die;
	}
}
foreach($access['table'] as $idx => $row)
{
	$row['id'] = $idx;
	if($acl[$idx] == "1")
		$row['enabled'] = TRUE;
	$accesslist[] = $row;
}

$layout['pagetitle'] = "Nowy administrator";
$SMARTY->assign('adminadd',$adminadd);
$SMARTY->assign('error',$error);
$SMARTY->assign('accesslist',$accesslist);
$SMARTY->display('adminadd.html');

?>
